@@ -3,7 +3,7 @@
 ## Purpose:     
 ## Author:      Alex Thuering
 ## Created:     2005/01/19
-## RCS-ID:      $Id: interfaces.py,v 1.32 2012/04/01 20:36:25 ntalex Exp $
+## RCS-ID:      $Id: interfaces.py,v 1.36 2013/10/15 19:30:41 ntalex Exp $
 ## Copyright:   (c) 2005 Alex Thuering
 ## Notes:		some modules adapted from svgl project
 ##############################################################################
@@ -352,13 +352,15 @@ for name in ["SVGLineElement", "SVGPolylineElement", "SVGPolygonElement",
 
 # SVGImageElement
 inter = interfaces["SVGImageElement"]
-inter.include_methods.append('    int GetDefaultWidth();\n')
-inter.include_methods.append('    int GetDefaultHeight();\n')
-inter.include_methods.append('    void SetDefaultSize();\n')
+inter.include_fwd_decls.append("ProgressDialog")
+inter.include_methods.append('    int GetDefaultWidth(wxProgressDialog* progressDlg = NULL);\n')
+inter.include_methods.append('    int GetDefaultHeight(wxProgressDialog* progressDlg = NULL);\n')
+inter.include_methods.append('    void SetDefaultSize(wxProgressDialog* progressDlg = NULL);\n')
 
 # SVGVideElement
 inter = interfaces["SVGVideoElement"]
-inter.include_methods.append('    double GetDuration();\n')
+inter.include_fwd_decls.append("ProgressDialog")
+inter.include_methods.append('    double GetDuration(wxProgressDialog* progressDlg = NULL);\n')
 
 # SVGTextElement
 inter = interfaces["SVGTextElement"]
@@ -389,14 +391,20 @@ inter.include_methods.append('''
     double GetQualifiedFx() const;
     double GetQualifiedFy() const;\n
 ''')
+# SVGRadialGradientElement
+
+inter = interface()
+interfaces["SVGAnimationElement"]=inter
+inter.include_methods.append('''
+    void ApplyAnimation();\n
+''')
 
 # SVGDocument
 inter = interface()
 interfaces["SVGDocument"]=inter
 
-inter.exclude_attributes = ["rootElement"]
-inter.include_attributes.append('''
-  protected:
+inter.exclude_attributes = ["rootElement", "title"]
+inter.include_attributes.append('''  protected:
     wxSVGCanvas* m_canvas;
     double m_scale;
     double m_scaleY;\n
@@ -412,6 +420,9 @@ inter.include_methods.append('''    wxSVGDocument() { Init(); }
     wxSVGDocument(const wxSVGDocument& doc);
     virtual ~wxSVGDocument();
     
+    virtual bool Load(const wxString& filename, const wxString& encoding = wxT("UTF-8"));
+    virtual bool Load(wxInputStream& stream, const wxString& encoding = wxT("UTF-8"));
+
     void Init();
     inline wxSVGCanvas* GetCanvas() { return m_canvas; }
     inline double GetScale() { return m_scale; }
@@ -419,25 +430,28 @@ inter.include_methods.append('''    wxSVGDocument() { Init(); }
     inline double GetScaleY() { return m_scaleY > 0 ? m_scaleY : m_scale; }
     const wxSVGMatrix& GetScreenCTM() { return m_screenCTM; }
     
-    wxSvgXmlElement* CreateElement(const wxString& tagName);
-    wxSvgXmlElement* CreateElementNS(const wxString& namespaceURI, const wxString& qualifiedName);
+    wxString GetTitle();
+    void SetTitle(const wxString& n);
     
     wxSVGSVGElement* GetRootElement() { return (wxSVGSVGElement*) GetRoot(); }
     void SetRootElement(wxSVGSVGElement* n) { SetRoot((wxSvgXmlElement*) n); }
     
     wxSVGElement* GetElementById(const wxString& id);
     
+    wxSvgXmlElement* CreateElement(const wxString& tagName);
+    wxSvgXmlElement* CreateElementNS(const wxString& namespaceURI, const wxString& qualifiedName);
+    
     double GetDuration();
     double GetCurrentTime() { return m_time; }
     void SetCurrentTime(double seconds);
     
     wxImage Render(int width = -1, int height = -1, const wxSVGRect* rect = NULL, bool preserveAspectRatio = true,
-		bool alpha = false);
+		bool alpha = false, wxProgressDialog* progressDlg = NULL);
     wxImage RenderElementById(const wxString& id);
   private:
       DECLARE_DYNAMIC_CLASS(wxSVGDocument)
 ''')
-inter.include_fwd_decls = ["SVGSVGElement","SVGElement","SVGCanvas"]
+inter.include_fwd_decls = ["SVGSVGElement","SVGElement","SVGCanvas","ProgressDialog"]
 inter.include_includes = ["SVGRect","SVGMatrix","<wx/image.h>"]
 inter.user_defined_contructor=1
 inter.user_defined_destructor=1
